Reference
=============

The Null data type
---------------------

.. automodule:: spyql.nulltype
   :members:


General SQL functions
--------------------------------

.. automodule:: spyql.sqlfuncs
   :members:


Aggregate functions
--------------------------------

.. automodule:: spyql.agg
   :members:


Dictionaries
--------------------------------

.. autoclass:: spyql.qdict.qdict
   :members:


Querying API
--------------------------------

.. automodule:: spyql.query
   :members:

.. automodule:: spyql.query_result
   :members:
